Documentation
¶
Index ¶
- type Accept
- type Accepted
- type Bitmask
- type Connect
- type DidResume
- type Disconnect
- type Disconnected
- type Entry
- type Event
- type Invalid
- type Network
- func (n *Network) Active() iter.Seq[signing.ID]
- func (n *Network) Apply(entry *Entry, emit func(Signal))
- func (n *Network) Clone() *Network
- func (n *Network) Connect(a, b signing.ID)
- func (n *Network) Connected() iter.Seq[signing.ID]
- func (n *Network) IsAcceptedBy(src, target signing.ID) bool
- func (n *Network) IsActive(id signing.ID) bool
- func (n *Network) IsKnown(id signing.ID) bool
- func (n *Network) IsResumed(id signing.ID) bool
- func (n *Network) IsResuming(id signing.ID) bool
- func (n *Network) MutuallyAccepted(id signing.ID) bool
- func (n *Network) NextHopTo(src, dst signing.ID) (signing.ID, bool)
- func (n *Network) State() State
- type Pause
- type Paused
- type Reject
- type Rejected
- type Resuming
- type Signal
- type State
- type Tick
- type Ticking
- type WhoAmI
- type WillResume
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Disconnect ¶
type Disconnected ¶
type Network ¶
type Network struct {
// contains filtered or unexported fields
}
func (*Network) NextHopTo ¶
NextHopTo returns the ID of the peer that src should send to in order to reach dst. BFS outward from dst; the first node found that is directly connected to src is the correct next hop. Since connections are symmetric, walking the graph in reverse is equivalent to walking it forward.
type WillResume ¶
type WillResume struct{}
Click to show internal directories.
Click to hide internal directories.